@@ -1,4 +1,4 @@
-"""This module helps check for valid moves in the context of a board."""
+"""Helps check for valid moves in the context of a board."""
 
 from nerdchess import pieces
 from nerdchess.move import Move
@@ -8,26 +8,21 @@ class BoardRules():
     """Applies different boardrules.
 
     Parameters:
-        move: The move to check against
-        board: The board to check against
+        move: The boardmove to check against
 
     Attributes:
         move: The move we're checking
-        board: The board we're checking
         valid: Is the checked move valid? see self.apply()
         origin: The origin square of the move
         destination: The destination square of the move
         piece: The piece being moved
     """
 
-    def __init__(self, move, board):
+    def __init__(self, move):
         """Init."""
         self.move = move
-        self.board = board
         self.valid = True
-        (self.origin,
-         self.destination) = self.move.get_origin_destination(self.board)
-        self.piece = self.origin.occupant
+        self.piece = self.move.origin_sq.occupant
         self.apply()
 
     def apply(self):
@@ -36,27 +31,29 @@ class BoardRules():
             self.__pawn_rules()
         if not isinstance(self.piece, pieces.Knight):
             self.__blocking_pieces()
-        if self.move.is_castling(self.board):
+        if self.move.is_castling():
             self.__castling()
         else:
-            if self.move.is_capturing(self.board):
+            if self.move.is_capturing():
                 self.__capturing()
             self.__self_checking()
 
     def __capturing(self):
-        if self.destination.occupant.color == self.origin.occupant.color:
+        """Check if this is a capturing move."""
+        if (self.move.destination_sq.occupant.color ==
+                self.move.origin_sq.occupant.color):
             self.valid = False
 
     def __pawn_rules(self):
         """Rules to apply to pawns only."""
         if self.move.horizontal == 1:
             # If we're going horizontal, are we at least capturing?
-            if not self.destination.occupant:
+            if not self.move.destination_sq.occupant:
                 d_letter = self.move.destination[0]
                 o_number = int(self.move.origin[1])
                 # If not, is it at least en passant?
                 if not isinstance(
-                        self.board.squares[d_letter][o_number].occupant,
+                        self.move.board.squares[d_letter][o_number].occupant,
                         pieces.Pawn):
                     self.valid = False
 
@@ -65,12 +62,12 @@ class BoardRules():
         for square in self.move.squares_between():
             c = square[0]
             i = int(square[1])
-            if self.board.squares[c][i].occupant:
+            if self.move.board.squares[c][i].occupant:
                 self.valid = False
 
     def __self_checking(self):
         """Check if the move puts the player itself in check."""
-        newboard = self.board.new_board(self.move)
+        newboard = self.move.board.new_board(self.move)
         if newboard.is_check() == self.piece.color:
             self.valid = False
 
@@ -78,7 +75,7 @@ class BoardRules():
         """Apply rules specific to castling."""
         pattern = []
 
-        if self.board.is_check() == self.piece.color:
+        if self.move.board.is_check() == self.piece.color:
             self.valid = False
 
         if self.move.horizontal > 0:
@@ -94,6 +91,6 @@ class BoardRules():
 
         for move in pattern:
             inter_move = Move.from_position(self.piece.position, move)
-            inter_board = self.board.new_board(inter_move)
+            inter_board = self.move.board.new_board(inter_move)
             if inter_board.is_check() == self.piece.color:
                 self.valid = False
