@@ -2,11 +2,6 @@
 
 The move is not aware of the board context, but is aware of the boundaries
 of a board in general.
-
-Todo:
-    - Currently the boundaries of a board are quite hardcoded
-    - Possibly make a class more suitable of describing a board
-        -- Make the current board class inherit from these boundaries
 """
 from abc import ABC
 from nerdchess.config import MOVE_REGEX, letterlist, numbers
@@ -17,19 +12,20 @@ class Move(ABC):
     Represents a move in a game of chess.
 
     Parameters:
-    move(String): A string that's tested with the regex '[a-h][1-8][a-h][1-8]'
+        move(String): A string that's tested with the regex
+                      '[a-h][1-8][a-h][1-8]'
 
     Attributes:
-    text(String): String representation of the move r'[a-h][1-8][a-h][1-8]'
-    origin(String): String representation of the origin square
-    destination(String): String representation of the destination square
-    horizontal(int): Amount of horizontal steps in the move
-    vertical(int): Amount of vertical steps in the move
-    indices(dict): Origin/destination letter(x)/number(y) mapped to their list
-                   position
+        text(String): String representation of the move r'[a-h][1-8][a-h][1-8]'
+        origin(String): String representation of the origin square
+        destination(String): String representation of the destination square
+        horizontal(int): Amount of horizontal steps in the move
+        vertical(int): Amount of vertical steps in the move
+        indices(dict): Origin/destination letter(x)/number(y) mapped to their
+                       list position
     """
 
-    def __init__(self, move):
+    def __init__(self, move, *args, **kwargs):
         """Init."""
         valid_move = MOVE_REGEX.match(move)
         if not valid_move:
@@ -78,7 +74,8 @@ class Move(ABC):
         move = "{}{}{}".format(position, new_letter, new_number)
         return cls(move)
 
-    # TODO Clean up this mess of a function
+    # TODO Should this be moved to boardmove?
+    # Or maybe some generator that implements this, returns the actual squres.
     def squares_between(self):
         """Return the squares between the origin and destination."""
         squares = []
@@ -89,43 +86,40 @@ class Move(ABC):
         if self.horizontal == -1 or self.vertical == -1:
             return squares
 
+        h_steps = 1 if self.horizontal > 0 else -1
+        v_steps = 1 if self.vertical > 0 else -1
+
         if self.is_diagonal():
-            steps = 1 if self.horizontal > 0 else -1
-            if self.vertical < 0 and steps == 1:
-                v_steps = -1
-            elif self.vertical > 0 and steps == -1:
-                v_steps = -1
-            else:
-                v_steps = 1
-
-            try:
-                for i in range(steps, self.horizontal, steps):
-                    step_index_x = self.indices['or']['x'] + i
-                    step_index_y = self.indices['or']['y'] + (i * v_steps)
-
-                    if step_index_x < 0 or step_index_y < 0:
-                        continue
-
-                    letter = letterlist[step_index_x]
-                    number = numbers[step_index_y]
-                    square = f"{letter}{number}"
-                    squares.append(square)
-            except IndexError:
-                pass
+            steps = h_steps
+            step_range = self.horizontal
         elif self.is_horizontal():
-            steps = 1 if self.horizontal > 0 else -1
-            for i in range(steps, self.horizontal, steps):
-                letter = letterlist[self.indices['or']['x'] + i]
-                number = self.origin[1]
-                square = f"{letter}{number}"
-                squares.append(square)
+            v_steps = 0
+            steps = h_steps
+            step_range = self.horizontal
         elif self.is_vertical():
-            steps = 1 if self.vertical > 0 else -1
-            for i in range(steps, self.vertical, steps):
-                letter = self.origin[0]
-                number = numbers[self.indices['or']['y'] + i]
-                square = f"{letter}{number}"
-                squares.append(square)
+            h_steps = 0
+            steps = v_steps
+            step_range = self.vertical
+
+        h_counter = h_steps
+        v_counter = v_steps
+
+        for i in range(steps, step_range, steps):
+            step_index_h = self.indices['or']['x'] + h_counter
+            step_index_v = self.indices['or']['y'] + v_counter
+
+            if step_index_v < 0 or step_index_h < 0:
+                h_counter = h_counter + h_steps
+                v_counter = v_counter + v_steps
+                continue
+
+            letter = letterlist[step_index_h]
+            number = numbers[step_index_v]
+            square = f"{letter}{number}"
+            squares.append(square)
+
+            h_counter = h_counter + h_steps
+            v_counter = v_counter + v_steps
 
         return squares
 
